@@ -1,8 +1,8 @@
 from pyspark.sql.functions import udf, lit
 from pyspark.sql.dataframe import DataFrame
 from labelbox.schema.data_row_metadata import DataRowMetadataKind
-from labelbase import Client as labelbaseClient
 from labelbox import Client as labelboxClient
+from labelbase.metadata import get_metadata_schema_to_name_key
 from pyspark.sql.types import StructType, StructField, StringType, MapType, ArrayType
 import json
 
@@ -12,14 +12,13 @@ def check_pyspark():
     except:
         raise RuntimeError(f'labelspark.Client() requires pyspark to be installed - please update your Databricks runtime to support pyspark')
 
-def create_upload_dict(table:DataFrame, lb_client:labelboxClient, base_client:labelbaseClient, row_data_col:str, 
+def create_upload_dict(table:DataFrame, lb_client:labelboxClient, row_data_col:str, 
                        global_key_col:str="", external_id_col:str="", metadata_index:dict={}, local_files:bool=False, 
                        divider:str="///", verbose=False):
     """ Uses UDFs to create a column of data row dictionaries to-be-uploaded, then converts this column into a list
     Args:
         table                       :   Required (pyspark.sql.dataframe.DataFrame) - Spark Table
         lb_client                   :   Required (labelbox.client.Client) - Labelbox Client object
-        base_client                 :   Required (labelbase.client.Client) - Labelbase Client object
         row_data_col                :   Required (str) - Column containing asset URL or file path
         global_key_col              :   Optional (str) - Column name containing the data row global key - defaults to row data
         external_id_col             :   Optional (str) - Column name containing the data row external ID - defaults to global key
@@ -34,7 +33,7 @@ def create_upload_dict(table:DataFrame, lb_client:labelboxClient, base_client:la
     """        
     global_key_col = global_key_col if global_key_col else row_data_col
     external_id_col = external_id_col if external_id_col else global_key_col  
-    metadata_name_key_to_schema = base_client.get_metadata_schema_to_name_key(lb_mdo=False, divider=divider, invert=True) 
+    metadata_name_key_to_schema = get_metadata_schema_to_name_key(client=lb_client, lb_mdo=False, divider=divider, invert=True) 
     uploads_table = create_uploads_column(
         table=table, lb_client=lb_client, row_data_col=row_data_col, global_key_col=global_key_col, external_id_col=external_id_col, 
         metadata_name_key_to_schema=metadata_name_key_to_schema, metadata_index=metadata_index
@@ -113,31 +112,34 @@ def __add_metadata_udf(metadata_value_col, data_row_col, metadata_field_name_key
         data_row_col['metadata_fields'].append({"schema_id":metadata_name_key_to_schema[str(metadata_field_name_key)],"value":input_metadata_value})
     return data_row_col
 
-def get_columns_function(table:DataFrame):
+def get_columns_function(table:DataFrame, extra_client=None):
     """Grabs all column names from a Pandas DataFrame
     Args:
         spark_table         :   Required (pyspark.sql.dataframe.DataFrame) - Spark Table
+        extra_client        :   Ignore this value - relevant to Labelbase library        
     Returns:
         List of strings corresponding to all column names
     """
     return [str(col[0]) for col in table.dtypes]
 
-def get_unique_values_function(table:DataFrame, column_name):
+def get_unique_values_function(table:DataFrame, column_name, extra_client=None):
     """ Grabs all unique values from a spark table column as strings
     Args:
         spark_table         :   Required (pyspark.sql.dataframe.DataFrame) - Databricks Spark Table object
         column_name         :   Required (str) - Spark Table column name
+        extra_client        :   Ignore this value - relevant to Labelbase library        
     Returns:
         List of unique values from a spark table column as strings
     """
     return [str(x.__getitem__(column_name)) for x in table.select(column_name).distinct().collect()]
 
-def add_column_function(table:DataFrame, column_name:str, default_value=""):
+def add_column_function(table:DataFrame, column_name:str, default_value="", extra_client=None):
     """ Adds a column of empty values to an existing Pandas DataFrame
     Args:
         spark_table         :   Required (pyspark.sql.dataframe.DataFrame) - Databricks Spark Table object
         column_name         :   Required (str) - Spark Table column name
         default_value       :   Optional (str) - Value to insert for every row in the newly created column
+        extra_client        :   Ignore this value - relevant to Labelbase library        
     Returns:
         Your table with a new column given the column_name and default_value  
     """
